CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
74 lines
2.5 KiB
C++
74 lines
2.5 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <chrono>
|
|
#include <hip_test_common.hh>
|
|
#include <utils.hh>
|
|
|
|
namespace hipStreamCreateWithFlagsTests {
|
|
|
|
HIP_TEST_CASE(Unit_hipStreamCreateWithFlags_Negative_NullStream) {
|
|
HIP_CHECK_ERROR(hipStreamCreateWithFlags(nullptr, hipStreamDefault), hipErrorInvalidValue);
|
|
}
|
|
|
|
HIP_TEST_CASE(Unit_hipStreamCreateWithFlags_Negative_InvalidFlag) {
|
|
hipStream_t stream{};
|
|
unsigned int flag = 0xFF;
|
|
REQUIRE(flag != hipStreamDefault);
|
|
REQUIRE(flag != hipStreamNonBlocking);
|
|
HIP_CHECK_ERROR(hipStreamCreateWithFlags(&stream, flag), hipErrorInvalidValue);
|
|
}
|
|
|
|
// create a stream and check the properties are correctly set
|
|
HIP_TEST_CASE(Unit_hipStreamCreateWithFlags_Default) {
|
|
const unsigned int flagUnderTest = GENERATE(hipStreamDefault, hipStreamNonBlocking);
|
|
hipStream_t stream{};
|
|
HIP_CHECK(hipStreamCreateWithFlags(&stream, flagUnderTest));
|
|
|
|
unsigned int flag{};
|
|
HIP_CHECK(hipStreamGetFlags(stream, &flag));
|
|
REQUIRE(flag == flagUnderTest);
|
|
|
|
int priority{};
|
|
HIP_CHECK(hipStreamGetPriority(stream, &priority));
|
|
// zero is considered default priority
|
|
REQUIRE(priority == 0);
|
|
|
|
HIP_CHECK(hipStreamDestroy(stream));
|
|
}
|
|
|
|
// a stream will default to blocking the null stream, but will not block the null stream when
|
|
// created with hipStreamNonBlocking
|
|
#if HT_AMD /* Disabled because frequency based wait is timing out on nvidia platforms */
|
|
HIP_TEST_CASE(Unit_hipStreamCreateWithFlags_DefaultStreamInteraction) {
|
|
const hipStream_t defaultStream = GENERATE(static_cast<hipStream_t>(nullptr), hipStreamPerThread);
|
|
const unsigned int flagUnderTest = GENERATE(hipStreamDefault, hipStreamNonBlocking);
|
|
CAPTURE(defaultStream, flagUnderTest);
|
|
|
|
hipStream_t stream{};
|
|
HIP_CHECK(hipStreamCreateWithFlags(&stream, flagUnderTest));
|
|
|
|
const auto delay = std::chrono::milliseconds(isQuickLevel() ? 100 : 500);
|
|
|
|
SECTION("default stream waiting for created stream") {
|
|
const hipError_t expectedError =
|
|
(flagUnderTest == hipStreamDefault) && (defaultStream == nullptr) ? hipErrorNotReady
|
|
: hipSuccess;
|
|
LaunchDelayKernel(delay, stream);
|
|
REQUIRE(hipStreamQuery(defaultStream) == expectedError);
|
|
}
|
|
SECTION("created stream waiting for default stream") {
|
|
LaunchDelayKernel(delay, defaultStream);
|
|
REQUIRE(hipStreamQuery(stream) == hipSuccess);
|
|
}
|
|
|
|
HIP_CHECK(hipDeviceSynchronize());
|
|
HIP_CHECK(hipStreamDestroy(stream));
|
|
}
|
|
#endif
|
|
|
|
} // namespace hipStreamCreateWithFlagsTests
|